pub struct Server {
pub build: Build,
pub backends: Set,
pub executable: PathBuf,
}Expand description
A server instance.
Fields
build: Buildbackends: SetThe available backends of the Server.
executable: PathBufThe path to the executable binary of the Server.
Implementations
Sourceimpl Server
impl Server
Sourcepub async fn list() -> Result<Vec<Build>, Error>
pub async fn list() -> Result<Vec<Build>, Error>
Lists all the Server builds installed in the system.