pub struct Settings {
pub host: String,
pub port: u32,
pub gpu_layers: u32,
pub stdin: Stdio,
pub stdout: Stdio,
pub stderr: Stdio,
}Expand description
The configurable options of a new Instance.
Fields
host: StringThe host URI that should be listened to by the Instance.
port: u32The host port to the Instance should be binded to.
gpu_layers: u32The amount of layers to run in a GPU backend.
stdin: StdioThe standard input stream.
stdout: StdioThe standard output stream.
stderr: StdioThe standard error stream.